@@ -1,30 +1,23 @@
 """Responsible for configuring io operations for input data."""
 # pylint: disable=too-few-public-methods
-__all__ = ["Foo", "Bar", "StagedFoo", "StagedBar", "FinalFoo", "FinalBar"]
+__all__ = ["InputIO", "StagedFoo", "StagedBar"]
 
-from sqlalchemy import Column, Float, String
 from sqlalchemy.ext.declarative import declarative_base
 
-from dynamicio import UnifiedIO, WithKafka, WithLocal, WithPostgres, WithS3File
+from dynamicio import UnifiedIO, WithLocal, WithPostgres, WithS3File
 from dynamicio.core import SCHEMA_FROM_FILE, DynamicDataIO
 
 Base = declarative_base()
 
 
-class Foo(UnifiedIO):
+class InputIO(UnifiedIO):
     """UnifiedIO subclass for V6 data."""
 
     schema = SCHEMA_FROM_FILE
 
 
-class Bar(UnifiedIO):
-    """UnifiedIO subclass for cargo movements volumes data."""
-
-    schema = SCHEMA_FROM_FILE
-
-
 class StagedFoo(WithS3File, WithLocal, DynamicDataIO):
-    """UnifiedIO subclass for staged foos6."""
+    """UnifiedIO subclass for staged foos."""
 
     schema = {
         "column_a": "object",
@@ -43,15 +36,3 @@ class StagedBar(WithLocal, WithPostgres, DynamicDataIO):
         "column_c": "int64",
         "column_d": "int64",
     }
-
-
-class FinalFoo(UnifiedIO):
-    """UnifiedIO subclass for V6 data."""
-
-    schema = SCHEMA_FROM_FILE
-
-
-class FinalBar(WithLocal, WithKafka, DynamicDataIO):
-    """UnifiedIO subclass for cargo movements volumes data."""
-
-    schema = SCHEMA_FROM_FILE
