@@ -3,7 +3,7 @@ import os
 import pickle
 import pickletools
 import tempfile
-from unittest.mock import patch, Mock
+from unittest.mock import Mock, patch
 
 import numpy as np
 import pandas as pd
@@ -308,8 +308,13 @@ def expected_s3_parquet_df():
 
 
 @pytest.fixture(scope="class")
-def expected_s3_hdf_df():
-    return pd.read_hdf(f"{constants.TEST_RESOURCES}/data/input/some_hdf_to_read.h5")
+def expected_s3_hdf_file_path():
+    return f"{constants.TEST_RESOURCES}/data/input/some_hdf_to_read.h5"
+
+
+@pytest.fixture(scope="class")
+def expected_s3_hdf_df(expected_s3_hdf_file_path):  # pylint: disable=redefined-outer-name
+    return pd.read_hdf(expected_s3_hdf_file_path)
 
 
 @pytest.fixture(scope="class")
